# Quple

A framework for quantum machine learning using the google cirq library

## Encoding Circuit

* Tutorial I: [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/AlkaidCheng/GSOC_MLHEP/blob/master/Deployment/Feature_Map/Feature_Map_Walkthrough.ipynb)

## Variational Circuit

* Tutorial I: [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/AlkaidCheng/GSOC_MLHEP/blob/master/Deployment/Trial_Wavefunction/Trial_Wavefunction_Walkthrough.ipynb)

## Parameterised Circuit Tutorial
* Tutorial I: [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/AlkaidCheng/GSOC_MLHEP/blob/master/Deployment/ParamResolver/EncodingCircuitWithParamResolver.ipynb)

## Circuit Descriptors
* Tutorial : [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/AlkaidCheng/GSOC_MLHEP/blob/master/Deployment/Circuit_Descriptors/Properties_of_PQC.ipynb)

## Variational Quantum Classifer
* Tutorial : [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/AlkaidCheng/GSOC_MLHEP/blob/master/Variational_Quantum_Classifier_Walkthrough.ipynb)

## General Features
* Tutorial : [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/AlkaidCheng/GSOC_MLHEP/blob/master/New_Features_Walkthrough.ipynb)

### Feature Updtes
* Tutorial : [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/AlkaidCheng/GSOC_MLHEP/blob/master/Feature_Updates_Jul_7.ipynb)
